@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2007 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "termlabel.h"
 
@@ -55,7 +40,7 @@ using namespace GlossaryNS;
 // //         return QLabel::event(event);
 // //
 // // //         qCWarning(LOKALIZE_LOG) << "dsds " << m_termTransl;
-// //     emit insertTerm(m_termTransl);
+// //     Q_EMIT insertTerm(m_termTransl);
 // //     return true;
 // // }
 
@@ -85,7 +70,7 @@ void TermLabel::insert()
     if (m_capFirst && !termTrans.isEmpty())
         termTrans[0] = termTrans.at(0).toUpper();
 
-    emit insertTerm(termTrans);
+    Q_EMIT insertTerm(termTrans);
 }
 
 void TermLabel::mousePressEvent(QMouseEvent* event)
@@ -121,7 +106,7 @@ void TermLabel::setText(const QString& term, const QByteArray& entryId, bool cap
 void QueryResultBtn::insert()
 {
 //     qCWarning(LOKALIZE_LOG)<<"ins "<<text();
-    emit insertText(m_text);
+    Q_EMIT insertText(m_text);
 }
 
 QueryResultBtn::QueryResultBtn(QAction* a)
@@ -135,7 +120,7 @@ QueryResultBtn::QueryResultBtn(QAction* a)
 
 void QueryResultBtn::mousePressEvent(QMouseEvent*/* event*/)
 {
-    emit insertText(m_text);
+    Q_EMIT insertText(m_text);
 }
 
 #endif
