@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "tmview.h"
 
@@ -128,7 +113,7 @@ void TextBrowser::mouseDoubleClickEvent(QMouseEvent* event)
 
     QString sel = textCursor().selectedText();
     if (!(sel.isEmpty() || sel.contains(' ')))
-        emit textInsertRequested(sel);
+        Q_EMIT textInsertRequested(sel);
 }
 
 
@@ -198,7 +183,8 @@ void TMView::dragEnterEvent(QDragEnterEvent* event)
 void TMView::dropEvent(QDropEvent *event)
 {
     QStringList files;
-    foreach (const QUrl& url, event->mimeData()->urls())
+    const auto urls = event->mimeData()->urls();
+    for (const QUrl& url : urls)
         files.append(url.toLocalFile());
     if (scanRecursive(files, Project::instance()->projectID()))
         event->acceptProposedAction();
@@ -285,7 +271,7 @@ void TMView::slotBatchSelectDone()
             insertCatalogString(m_catalog, pos, entry.target, 0);
 
             if (Q_UNLIKELY(m_pos.entry == pos.entry && pos.form == m_pos.form))
-                emit refreshRequested();
+                Q_EMIT refreshRequested();
 
         }
         if (!insHappened) {
@@ -457,7 +443,7 @@ void TMView::slotSuggestionsCame(SelectJob* j)
     QTextCharFormat noncloseMatchCharFormat;
     QTextCharFormat closeMatchCharFormat;
     closeMatchCharFormat.setFontWeight(QFont::Bold);
-    forever {
+    while (true) {
         QTextCursor cur = m_browser->textCursor();
         QString html;
         html.reserve(1024);
@@ -619,7 +605,7 @@ void TMView::contextMenu(const QPoint& pos)
     if (r->data().toInt() == Remove) {
         removeEntry(e);
     } else if (r->data().toInt() == Open) {
-        emit fileOpenRequested(e.file, e.source.string, e.ctxt, true);
+        Q_EMIT fileOpenRequested(e.file, e.source.string, e.ctxt, true);
     } else if ((r->data().toInt() == RemoveFile) &&
                KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this missing file:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.file, e.dbName),
                        i18nc("@title:window", "Translation Memory Missing File Removal"))) {
@@ -1017,6 +1003,6 @@ void TMView::slotUseSuggestion(int i)
 
     m_catalog->endMacro();
 
-    emit refreshRequested();
+    Q_EMIT refreshRequested();
 }
 
